package Core::Debian::Apt;

use strict;
use warnings;

use base 'Resmon::Module';

use Resmon::ExtComm qw(run_command cache_command);

=pod

=head1 NAME

Core::Ubuntu::Apt - monitor apt status

=head1 SYNOPSIS

 Core::Debian::Apt {
     packages: noop
 }

=head1 DESCRIPTION

This module checks for apt packages waiting for updates.
It assumes that apt-get update is being run by another process as it likely
does not have permission to run it.

=head1 CONFIGURATION

=over

=item critical_number

Number of waiting non-security packages to return warning or critical value.

=head1 METRICS

=over

=item total

The number of packages waiting

=item security

The number of security packages waiting

=back

=cut

sub handler {
    my $self = shift;
    my $config = $self->{config}; # All configuration is in here
    my $critical_number = 500;
    my $apt_command = '/usr/lib/nagios/plugins/check_apt';
    my $use_dist = 0;

    my $output = run_command($apt_command);
    chomp $output;

    my ($a, $total, $security) =
        $output =~ /APT (OK|WARNING|CRITICAL): ([0-9.]+) packages available for upgrade \(([0-9.]+) critical updates\)./;

    my $status = "OK";

    if ($total > $critical_number) {
        $status = "WARNING";
    }
    if ($security > 0) {
        $status = "BAD";
    }

    return {
        "severity" => [$status  , "s"],
        "total"    => [$total   , "I"],
        "security" => [$security, "I"],
    };
};

1;

