package Core::Postfix;

use strict;
use warnings;

use base 'Resmon::Module';

use Resmon::ExtComm qw(run_command cache_command);

=pod

=head1 NAME

Core::Postfix - Monitor postfix statistics using qshape

=head1 SYNOPSIS

 Core::Postfix {
     total    	: noop
     gmail.com  : noop
 }

=head1 DESCRIPTION

This module uses the postfix command line tool qshape and its output format to check
on the queues of the postfix mailer running on the local machine.

=head1 CONFIGURATION

=over

=item 'total'

This configuration key look up with the `qshape <name>` for the names "incoming",
"active", "deferred" and "hold", and returned the total number of messages in each 
of the queues.

=back

=item check_name

This configuration key look up with the `qshape <name>` for the queues "incoming",
"active", "deferred" and "hold", and returned the total number of messages in each 
of the queues for the domain specified by check_name, both as recipient domain 
and as a sender domain.

=back
=cut

my $DEBUG=0;
sub handler {
    my $self = shift;
    my $config = $self->{config};
    my $wanted_pairs;
    my $wanted_age = $self->{config}->{age} || 7*24*60;
    my $domain=$self->{config}->{domain} || 'total';
    my $check=$self->{check_name};
    if($domain eq 'total') {
        for my $queue ('incoming', 'active', 'deferred', 'hold') {
            my $raw_lines = run_command("/usr/sbin/qshape -t $wanted_age $queue");
            my @lines = split /\n/, $raw_lines;
            if(!@lines) {
                die "Error running `/usr/sbin/qshape\n";
            }
            my @Total_line = grep(/TOTAL/,@lines);
            my @total_numb = split / +/, $Total_line[0];
            if ($DEBUG) { print STDERR "queue=$queue, check=$check, ",join(":",@total_numb), "\n"}
            ${$wanted_pairs}{$queue} = [$total_numb[2]-$total_numb[3],"i"];
        }
    }
    else {
        for my $queue ('incoming', 'active', 'deferred', 'hold') {
            my $raw_lines = run_command("/usr/sbin/qshape -t $wanted_age $queue");
            my @lines = split /\n/, $raw_lines;
            if(!@lines) {
                die "Error running `/usr/sbin/qshape\n";
            }
            my @Domain_line = grep(/ $domain/,@lines);
            my @Domain_numb = split / +/, $Domain_line[0];
            $Domain_numb[2]=0 if not $Domain_numb[2];
            $Domain_numb[3]=0 if not $Domain_numb[3];
            if ($DEBUG) { print STDERR "RCPT:check=$check,domain=$domain,$queue=$queue,",join(":",@Domain_numb), "\n"}
            ${$wanted_pairs}{$queue.'.rcp.'.$domain} = [$Domain_numb[2]-$Domain_numb[3],"i"];
            $raw_lines = run_command("/usr/sbin/qshape -t $wanted_age -s $queue");
            @lines = split /\n/, $raw_lines;
            if(!@lines) {
                die "Error running `/usr/sbin/qshape\n";
            }
            @Domain_line = grep(/ $domain/,@lines);
            @Domain_numb = split / +/, $Domain_line[0];
            $Domain_numb[2]=0 if not $Domain_numb[2];
            $Domain_numb[3]=0 if not $Domain_numb[3];
            if ($DEBUG) { print STDERR "SND:check=$check,domain=$domain,$queue=$queue,",join(":",@Domain_numb), "\n"}
            ${$wanted_pairs}{$queue.'.snd.'.$domain} = [$Domain_numb[2]-$Domain_numb[3],"i"];
        }
    }
    return $wanted_pairs;
};

1;
